==> chaosmesh-model-5.3.2-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/HTTPChaosSpecBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class HTTPChaosSpecBuilder extends HTTPChaosSpecFluentImpl<HTTPChaosSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<HTTPChaosSpec,HTTPChaosSpecBuilder> {

    HTTPChaosSpecFluent<?> fluent;
    Boolean validationEnabled;

    public HTTPChaosSpecBuilder() {
        this(true);
    }

    public HTTPChaosSpecBuilder(Boolean validationEnabled) {
        this(new HTTPChaosSpec(), validationEnabled);
    }

    public HTTPChaosSpecBuilder(HTTPChaosSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public HTTPChaosSpecBuilder(HTTPChaosSpecFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new HTTPChaosSpec(), validationEnabled);
    }

    public HTTPChaosSpecBuilder(HTTPChaosSpecFluent<?> fluent,HTTPChaosSpec instance) {
        this(fluent, instance, true);
    }

    public HTTPChaosSpecBuilder(HTTPChaosSpecFluent<?> fluent,HTTPChaosSpec instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withAction(instance.getAction()); 
        fluent.withDuration(instance.getDuration()); 
        fluent.withHeaders(instance.getHeaders()); 
        fluent.withMode(instance.getMode()); 
        fluent.withPercent(instance.getPercent()); 
        fluent.withScheduler(instance.getScheduler()); 
        fluent.withSelector(instance.getSelector()); 
        fluent.withValue(instance.getValue()); 
        this.validationEnabled = validationEnabled; 
    }

    public HTTPChaosSpecBuilder(HTTPChaosSpec instance) {
        this(instance,true);
    }

    public HTTPChaosSpecBuilder(HTTPChaosSpec instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withAction(instance.getAction()); 
        this.withDuration(instance.getDuration()); 
        this.withHeaders(instance.getHeaders()); 
        this.withMode(instance.getMode()); 
        this.withPercent(instance.getPercent()); 
        this.withScheduler(instance.getScheduler()); 
        this.withSelector(instance.getSelector()); 
        this.withValue(instance.getValue()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.chaosmesh.v1alpha1.EditableHTTPChaosSpec build() {
        EditableHTTPChaosSpec buildable = new EditableHTTPChaosSpec(fluent.getAction(),fluent.getDuration(),fluent.getHeaders(),fluent.getMode(),fluent.getPercent(),fluent.getScheduler(),fluent.getSelector(),fluent.getValue());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        HTTPChaosSpecBuilder that = (HTTPChaosSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> chaosmesh-model-5.4.1-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/HTTPChaosSpecBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class HTTPChaosSpecBuilder extends io.fabric8.chaosmesh.v1alpha1.HTTPChaosSpecFluentImpl<io.fabric8.chaosmesh.v1alpha1.HTTPChaosSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.chaosmesh.v1alpha1.HTTPChaosSpec,io.fabric8.chaosmesh.v1alpha1.HTTPChaosSpecBuilder> {

    io.fabric8.chaosmesh.v1alpha1.HTTPChaosSpecFluent<?> fluent;
    java.lang.Boolean validationEnabled;

    public HTTPChaosSpecBuilder() {
        this(true);
    }

    public HTTPChaosSpecBuilder(java.lang.Boolean validationEnabled) {
        this(new HTTPChaosSpec(), validationEnabled);
    }

    public HTTPChaosSpecBuilder(io.fabric8.chaosmesh.v1alpha1.HTTPChaosSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public HTTPChaosSpecBuilder(io.fabric8.chaosmesh.v1alpha1.HTTPChaosSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
        this(fluent, new HTTPChaosSpec(), validationEnabled);
    }

    public HTTPChaosSpecBuilder(io.fabric8.chaosmesh.v1alpha1.HTTPChaosSpecFluent<?> fluent,io.fabric8.chaosmesh.v1alpha1.HTTPChaosSpec instance) {
        this(fluent, instance, true);
    }

    public HTTPChaosSpecBuilder(io.fabric8.chaosmesh.v1alpha1.HTTPChaosSpecFluent<?> fluent,io.fabric8.chaosmesh.v1alpha1.HTTPChaosSpec instance,java.lang.Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withAction(instance.getAction()); 
        fluent.withDuration(instance.getDuration()); 
        fluent.withHeaders(instance.getHeaders()); 
        fluent.withMode(instance.getMode()); 
        fluent.withPercent(instance.getPercent()); 
        fluent.withScheduler(instance.getScheduler()); 
        fluent.withSelector(instance.getSelector()); 
        fluent.withValue(instance.getValue()); 
        this.validationEnabled = validationEnabled; 
    }

    public HTTPChaosSpecBuilder(io.fabric8.chaosmesh.v1alpha1.HTTPChaosSpec instance) {
        this(instance,true);
    }

    public HTTPChaosSpecBuilder(io.fabric8.chaosmesh.v1alpha1.HTTPChaosSpec instance,java.lang.Boolean validationEnabled) {
        this.fluent = this; 
        this.withAction(instance.getAction()); 
        this.withDuration(instance.getDuration()); 
        this.withHeaders(instance.getHeaders()); 
        this.withMode(instance.getMode()); 
        this.withPercent(instance.getPercent()); 
        this.withScheduler(instance.getScheduler()); 
        this.withSelector(instance.getSelector()); 
        this.withValue(instance.getValue()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.chaosmesh.v1alpha1.EditableHTTPChaosSpec build() {
        EditableHTTPChaosSpec buildable = new EditableHTTPChaosSpec(fluent.getAction(),fluent.getDuration(),fluent.getHeaders(),fluent.getMode(),fluent.getPercent(),fluent.getScheduler(),fluent.getSelector(),fluent.getValue());
        return buildable;
    }

    public boolean equals(java.lang.Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        HTTPChaosSpecBuilder that = (HTTPChaosSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
